@@ -1,7 +1,7 @@
 import pytest
 from torch.utils.data import DataLoader
 from spotPython.data.diabetes import Diabetes
-from spotPython.light.netlightregression import NetLightRegression
+from spotPython.light.regression.netlightregression import NetLightRegression
 from torch import nn
 import lightning as L
 
