@@ -1,6 +1,6 @@
 import pytest
 from spotPython.utils.init import fun_control_init
-from spotPython.light.netlightregression import NetLightRegression
+from spotPython.light.regression.netlightregression import NetLightRegression
 from spotPython.hyperdict.light_hyper_dict import LightHyperDict
 from spotPython.hyperparameters.values import add_core_model_to_fun_control, get_default_hyperparameters_as_array
 from spotPython.data.diabetes import Diabetes
